# cscs

A utility library for managing and retrieving version information from a version.json file, 
with additional tools such as a logger and more.

## 📦 Installation

Install from PyPI:

```bash
pip install cscs
```

## 🧪 Samples

For examples of how to use tools included in this library, check the `/sample` folder.  
Each package has a corresponding `<package>_sample.py` file demonstrating its usage.

### Sample Code Links

* [version_sample.py](https://github.com/lendoo73/cscs-tools/blob/main/sample/version/version_sample.py)
* [logger_sample.py](https://github.com/lendoo73/cscs-tools/blob/main/sample/logger/logger_sample.py)

## 📝 License

MIT © Csaba Cselko
